@@ -257,8 +257,8 @@ def render_table(data, append_headers, append_lineno):
     length = 22
     n = math.ceil(len(data["rows"]) / length)
     html = []
-    rows = []
-    for index in range(0, n+1):
+    data_rows = []
+    for index in range(0, n+2):
         html.append(
             "<table  "
             'style="border-collapse: collapse" '
@@ -280,40 +280,41 @@ def render_table(data, append_headers, append_lineno):
         html.append("</colgroup>")
         append_headers(data, html)
         if index > 0:
-            rows.append(data["rows"][0:2])
-            rows.append(data["rows"][index*length:(index+1)*length])
+            data_rows.append(data["rows"][0:2])
+            data_rows.append(data["rows"][index*length:(index+1)*length])
         else :
-            rows.append(data["rows"][0:length])
-        for i, row in enumerate(data["rows"][index*length:(index+1)*length]):
-            trow = [('<tr id="{}-{}-of-{}-for-data-{}-of-{}">').format(i, index, n,index*length,index+1*length)]
-            append_lineno(trow, i)
-            for cell in row:
-                if cell["column"] in hidden_columns:
-                    continue
-                images = data["images"].get((cell["column"], cell["row"])) or []
-                formatted_images = []
-                for img in images:
-                    styles = render_inline_styles(img["style"])
-                    img_tag = (
-                        '<img width="{width}" height="{height}"'
-                        'style="{styles_str}"'
-                        'src="{src}"'
-                        "/>"
-                    ).format(styles_str=styles, **img)
-                    formatted_images.append(img_tag)
-                trow.append(
-                    (
-                        '<td {attrs_str} style="{styles_str}">'
-                        "{formatted_images}"
-                        "{formatted_value}"
-                        "</td>"
-                    ).format(
-                        attrs_str=render_attrs(cell["attrs"]),
-                        styles_str=render_inline_styles(cell["style"]),
-                        formatted_images="\n".join(formatted_images),
-                        **cell,
-                    )
-                )
+            data_rows.append(data["rows"][index:length])
+        for row in data_rows:
+            trow = [('<tr id="{}-of-{}-for-data-{}-of-{}">').format(index, n+1,index*length,(index+1)*length)]
+            # append_lineno(trow, i)
+            trow.append(('{}').format(row))
+            # for cell in row:
+            #     if cell["column"] in hidden_columns:
+            #         continue
+            #     images = data["images"].get((cell["column"], cell["row"])) or []
+            #     formatted_images = []
+            #     for img in images:
+            #         styles = render_inline_styles(img["style"])
+            #         img_tag = (
+            #             '<img width="{width}" height="{height}"'
+            #             'style="{styles_str}"'
+            #             'src="{src}"'
+            #             "/>"
+            #         ).format(styles_str=styles, **img)
+            #         formatted_images.append(img_tag)
+            #     trow.append(
+            #         (
+            #             '<td {attrs_str} style="{styles_str}">'
+            #             "{formatted_images}"
+            #             "{formatted_value}"
+            #             "</td>"
+            #         ).format(
+            #             attrs_str=render_attrs(cell["attrs"]),
+            #             styles_str=render_inline_styles(cell["style"]),
+            #             formatted_images="\n".join(formatted_images),
+            #             **cell,
+            #         )
+            #     )
             trow.append("</tr>")
             html.append("\n".join(trow))
         html.append("</table>")
